function [ind] = vo_cornercut(ky,kz,nsize)
% VO_CORNERCUT cuts the corners of k-space 
%   IND = VO_CORNERCUT(KY,KZ,NSIZE) returns the indeces IND that specify
%   which elements in the KY and KZ array to keep. KY and KZ are normalized
%   between [-1,1). NSIZE is a two-element array describing the size of the
%   sampling mask.
%
%
%   (based on Miki's code for corner cut in Poisson disc sampling)
%
% (c) Joseph Y Cheng (jycheng@stanford.edu) 2014.
%
    
% SVN info: 
%     Date:     $Date: 2014-10-16 11:18:02 -0700 (Thu, 16 Oct 2014) $
%     Revision: $Revision: 1442 $
%     Author:   $Author: jycheng $
%     Id:       $Id: vo_cornercut.m 1442 2014-10-16 18:18:02Z jycheng $

        
    dny = 2;    
    ny  = nsize(1);
    nz  = nsize(2);
    
    yelledge = -1+2*(floor(ny/2)-1-dny)/(ny-1);
    ellmin = sqrt(1+yelledge^2);
    ndec = abs(floor(log10(ellmin-1)));        
    ellmin = 1+ceil((10^ndec)*(ellmin-1)+0.5)/10^ndec;
    ind = find((ky.^2+kz.^2)<=ellmin);
