function [mask] = vo_cornercutmask(nsize)
% VO_CORNERCUTMASK creates a mask with corners cut
%   MASK = VO_CORNERCUT(NSIZE) creates a sampling mask with size
%   specified by NSIZE -- a two element array. Corners of the
%   mask are "cut," or zero-ed out.
%
%   See also VO_VDRAD and VO_CAPR.
%
% (c) Joseph Y Cheng (jycheng@mrsrl.stanford.edu) 2014
%
    
% SVN info:
%     Date:     $Date: 2014-10-14 17:39:16 -0700 (Tue, 14 Oct 2014) $
%     Revision: $Revision: 1441 $
%     Author:   $Author: jycheng $
%     Id:       $Id: vo_vdrad.m 1441 2014-10-15 00:39:16Z jycheng $
    
    ny = nsize(1);
    nz = nsize(2);
    
    % Find initial ordering (based on seq)
    yi = repmat((1:ny),[nz 1]);
    zi = repmat((1:nz).',[1 ny]);
    yi = yi(:); zi = zi(:);
    
    % Convert ordering to k-space coordinate points
    %  normalized from (-1,1]
    ky = -1+2*(yi-.5)/ny;
    if nz>1
        kz = -1+2*(zi-.5)/nz;
    else
        kz = 0*zi;
    end

    ind = vo_cornercut(ky,kz,nsize);
    mask = zeros(nz,ny);
    mask(ind) = 1;
    mask = mask.';