function vo_draworder(yorder,zorder,fignum,tl)
% VO_DRAWORDER draws the (ky,kz) phase encodes
%   VO_DRAWORDER(YORDER,ZORDER,[FIGNUM],[TL]) draws the phase-encode
%   ordering specified by vectors YORDER and ZORDER. An optional (but
%   recommended) figure number parameter, FIGNUM, can be identified to draw
%   the animation in a specific figure. This function draws the phase encode
%   ordering as an image. The last optional parameter TL determines the
%   drawing speed: for each time increment, TL number of points are drawn.
%
%   See also VO_SEQ, VO_ELLIPCENT, VO_RADIAL, VO_CAPR, and VO_VDRAD.
%   See also VO_DRAWORDER_VID.
%
%   Depends on SFIGURE.
%
% (c) Joseph Y Cheng (jycheng@stanford.edu) 2012, 2013.
%

% SVN info: 
%   Date:     $Date: 2014-10-16 11:18:02 -0700 (Thu, 16 Oct 2014) $
%   Revision: $Revision: 1442 $
%   Author:   $Author: jycheng $
%   Id:       $Id: vo_draworder.m 1442 2014-10-16 18:18:02Z jycheng $
    
    %% if not specified, draw in current fig (not ideal)
    if nargin < 3 || isempty(fignum)
        fignum = gcf;
    end
    if nargin < 4
        tl = 1;
    end
    
    sfigure(fignum); hold off;
    mask = zeros(max(yorder),max(zorder));
    
    for N=tl:tl:length(yorder)
        ind = (N-tl)+(1:tl);
        mask = mask*0.9999;
        for I=ind
            mask(yorder(I),zorder(I))=1;
        end
        sfigure(fignum),imshow(mask,[]);
        drawnow;
    end

