function [yout,zout] = vo_ellipcent(yin,zin)
% VO_SEQ generates elliptical-centric view-ordering
%   [YO,ZO] = VO_SEQ(YI,ZI) generates elliptical-centric view-ordering based
%   on a list of KY and KZ pairs in YI and ZI.
%
%   Output:
%     YO -- [int] [nviews] ky ordering 
%     ZO -- [int] [nviews] kz ordering
%
%   Reference:
%     [1] Wilman AH and Riederer SJ. Performance of an elliptical centric
%         view order for signal enhancement and motion artifact suppression
%         in breath-hold three-dimensional gradient echo imaging. Magn Reson
%         Med 1997;38:793--802.
%
%   See also VO_SEQ, VO_RADIAL, VO_CAPR, and VO_VDRAD.
%   See also VO_DRAWORDER and VO_DRAWORDER_VID.
%
% (c) Joseph Y Cheng (jycheng@stanford.edu) 2013.
%
    
% SVN info: 
%     Date:     $Date: 2014-10-16 11:18:02 -0700 (Thu, 16 Oct 2014) $
%     Revision: $Revision: 1442 $
%     Author:   $Author: jycheng $
%     Id:       $Id: vo_ellipcent.m 1442 2014-10-16 18:18:02Z jycheng $ 
    
    y = yin - min(yin(:)); 
    z = zin - min(zin(:));
   
    ymax = max(y(:));
    ymid = ymax/2;    
    zmax = max(z(:));
    zmid = zmax/2;
    
    ky = (y-ymid)/ymax;
    kz = (z-zmid)/zmax;
    
    npe   = length(yin(:));
    yout = []; zout = []; 
    
    k = ky + i*kz;    
    v = [angle(k(:)),abs(k(:)),(1:length(k)).'];
    v = sortrows(v,[2 1]);

    yout = yin(v(:,end));
    zout = zin(v(:,end));
    
    