function [yo,zo] = vo_seq(yi,zi)
% VO_SEQ generates sequential view-ordering
%   [YO,ZO] = VO_SEQ(YI,ZI) generates sequential view-ordering based on
%   on a list of KY and KZ pairs in YI and ZI. 
%
%   Output:
%     YO -- [int] [nviews] ky ordering 
%     ZO -- [int] [nviews] kz ordering
%
%   See also VO_ELLIPCENT, VO_RADIAL, VO_CAPR, and VO_VDRAD.
%   See also VO_DRAWORDER and VO_DRAWORDER_VID.
%
% (c) Joseph Y Cheng (jycheng@stanford.edu) 2013.
%
    
% SVN info: 
%     Date:     $Date: 2014-10-16 11:18:02 -0700 (Thu, 16 Oct 2014) $
%     Revision: $Revision: 1442 $
%     Author:   $Author: jycheng $
%     Id:       $Id: vo_seq.m 1442 2014-10-16 18:18:02Z jycheng $
 
    
% This generates the sequential view-ordering based on a mask
%    [yout,zout] = meshgrid(1:size(mask,1),1:size(mask,2));    
%    yout = yout(find(mask(:)));
%    zout = zout(find(mask(:)));
    
    v = [yi(:) zi(:)];
    v = sortrows(v,[1 2]);
    
    yo = v(:,1);
    zo = v(:,2);